@@ -1,8 +1,6 @@
 #!/usr/bin/perl -T
 
-use 5.006;
-use v5.8;
-
+use 5.008;
 use strict;
 use warnings;
 
@@ -21,12 +19,12 @@ BEGIN {
     unshift @INC, File::Spec->catdir($cwd, 'lib');
 }
 
-use Test::Unit::Lite;
+use Test::Unit::Lite 0.10;
+use Test::Assert;
 
-use Exception::Base
-    max_arg_nums => 0, max_arg_len => 200, verbosity => 3,
-    '+ignore_package' => [ qr/^Test::Unit::/, 'File::Find', 'main' ];
-use Exception::Warning '%SIG' => 'die';
-use Exception::Died    '%SIG';
+use Exception::Base max_arg_nums => 0, max_arg_len => 200, verbosity => 4;
+use Exception::Warning '%SIG' => 'die', verbosity => 4;
+use Exception::Died '%SIG', verbosity => 4;
+use Exception::Assertion verbosity => 4;
 
 all_tests;
